@@ -19,18 +19,16 @@ sys.path.insert(0, os.path.abspath('..'))
 from configparser import ConfigParser
 from pathlib import Path
 
-config_file = (
-    Path(__file__).absolute().parent.parent / 'setup.cfg'
-)  # same folder as setup.py
+config_file = Path(__file__).absolute().parent.parent / 'setup.cfg'  # same folder as setup.py
 config = ConfigParser()
 config.read_file(open(config_file, 'r'))
 
 project = config['metadata']['name']
-copyright = config['metadata']['copyright']
-author = config['metadata']['author']
+copyright = config['metadata'].get('copyright', '')
+author = config['metadata'].get('author', '')
 
 # The full version, including alpha/beta/rc tags
-release = config['metadata']['version']
+release = config['metadata'].get('version', '')
 
 # -- General configuration ---------------------------------------------------
 
